==> libreoffice-still-debug-25.2.7-6-x86_64.pkg.tar.zst: usr/src/debug/libreoffice-still/libreoffice-25.2.7.2/workdir/UnoApiHeadersTarget/offapi/normal/com/sun/star/document/UndoContextNotClosedException.hpp <==
#ifndef INCLUDED_COM_SUN_STAR_DOCUMENT_UNDOCONTEXTNOTCLOSEDEXCEPTION_HPP
#define INCLUDED_COM_SUN_STAR_DOCUMENT_UNDOCONTEXTNOTCLOSEDEXCEPTION_HPP

#include "sal/config.h"

#include "com/sun/star/document/UndoContextNotClosedException.hdl"

#include "com/sun/star/util/InvalidStateException.hpp"
#include "com/sun/star/uno/Type.hxx"
#include "cppu/unotype.hxx"

namespace com { namespace sun { namespace star { namespace document {

inline UndoContextNotClosedException::UndoContextNotClosedException(
#if defined LIBO_USE_SOURCE_LOCATION
    LIBO_USE_SOURCE_LOCATION::source_location location
#endif
    )
    : ::css::util::InvalidStateException(
#if defined LIBO_USE_SOURCE_LOCATION
    location
#endif
)
{ }

inline UndoContextNotClosedException::UndoContextNotClosedException(const ::rtl::OUString& Message_, const ::css::uno::Reference< ::css::uno::XInterface >& Context_
#if defined LIBO_USE_SOURCE_LOCATION
    , LIBO_USE_SOURCE_LOCATION::source_location location
#endif
)
    : ::css::util::InvalidStateException(Message_, Context_
#if defined LIBO_USE_SOURCE_LOCATION
    , location
#endif
)
{ }

#if !defined LIBO_INTERNAL_ONLY
UndoContextNotClosedException::UndoContextNotClosedException(UndoContextNotClosedException const & the_other): ::css::util::InvalidStateException(the_other) {}

UndoContextNotClosedException::~UndoContextNotClosedException() {}

UndoContextNotClosedException & UndoContextNotClosedException::operator =(UndoContextNotClosedException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::css::util::InvalidStateException::operator =(the_other);
    return *this;
}
#endif

} } } }

namespace com { namespace sun { namespace star { namespace document {

inline ::css::uno::Type const & cppu_detail_getUnoType(SAL_UNUSED_PARAMETER ::css::document::UndoContextNotClosedException const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.document.UndoContextNotClosedException" );
    }
    return * reinterpret_cast< ::css::uno::Type * >( &the_type );
}

} } } }

SAL_DEPRECATED("use cppu::UnoType") inline ::css::uno::Type const & SAL_CALL getCppuType(SAL_UNUSED_PARAMETER ::css::document::UndoContextNotClosedException const *) {
    return ::cppu::UnoType< ::css::document::UndoContextNotClosedException >::get();
}

#endif // INCLUDED_COM_SUN_STAR_DOCUMENT_UNDOCONTEXTNOTCLOSEDEXCEPTION_HPP

==> libreoffice-still-debug-25.8.5-2-x86_64.pkg.tar.zst: usr/src/debug/libreoffice-still/libreoffice-25.8.5.2/workdir/UnoApiHeadersTarget/offapi/normal/com/sun/star/document/UndoContextNotClosedException.hpp <==
#ifndef INCLUDED_COM_SUN_STAR_DOCUMENT_UNDOCONTEXTNOTCLOSEDEXCEPTION_HPP
#define INCLUDED_COM_SUN_STAR_DOCUMENT_UNDOCONTEXTNOTCLOSEDEXCEPTION_HPP

#include "sal/config.h"

#include "com/sun/star/document/UndoContextNotClosedException.hdl"

#include "com/sun/star/util/InvalidStateException.hpp"
#include "com/sun/star/uno/Type.hxx"
#include "cppu/unotype.hxx"

namespace com { namespace sun { namespace star { namespace document {

inline UndoContextNotClosedException::UndoContextNotClosedException(
#if defined LIBO_USE_SOURCE_LOCATION
    o3tl::source_location location
#endif
)
    : ::css::util::InvalidStateException(
#if defined LIBO_USE_SOURCE_LOCATION
    location
#endif
)
{ }

inline UndoContextNotClosedException::UndoContextNotClosedException(const ::rtl::OUString& Message_, const ::css::uno::Reference< ::css::uno::XInterface >& Context_
#if defined LIBO_USE_SOURCE_LOCATION
    , o3tl::source_location location
#endif
)
    : ::css::util::InvalidStateException(Message_, Context_
#if defined LIBO_USE_SOURCE_LOCATION
    , location
#endif
)
{ }

#if !defined LIBO_INTERNAL_ONLY
UndoContextNotClosedException::UndoContextNotClosedException(UndoContextNotClosedException const & the_other): ::css::util::InvalidStateException(the_other) {}

UndoContextNotClosedException::~UndoContextNotClosedException() {}

UndoContextNotClosedException & UndoContextNotClosedException::operator =(UndoContextNotClosedException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::css::util::InvalidStateException::operator =(the_other);
    return *this;
}
#endif

} } } }

namespace com { namespace sun { namespace star { namespace document {

inline ::css::uno::Type const & cppu_detail_getUnoType(SAL_UNUSED_PARAMETER ::css::document::UndoContextNotClosedException const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.document.UndoContextNotClosedException" );
    }
    return * reinterpret_cast< ::css::uno::Type * >( &the_type );
}

} } } }

SAL_DEPRECATED("use cppu::UnoType") inline ::css::uno::Type const & SAL_CALL getCppuType(SAL_UNUSED_PARAMETER ::css::document::UndoContextNotClosedException const *) {
    return ::cppu::UnoType< ::css::document::UndoContextNotClosedException >::get();
}

#endif // INCLUDED_COM_SUN_STAR_DOCUMENT_UNDOCONTEXTNOTCLOSEDEXCEPTION_HPP
